summaryrefslogtreecommitdiffstats
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/main/java/org/bukkit/World.java4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/main/java/org/bukkit/World.java b/src/main/java/org/bukkit/World.java
index b465c866..e53c1f12 100644
--- a/src/main/java/org/bukkit/World.java
+++ b/src/main/java/org/bukkit/World.java
@@ -303,9 +303,9 @@ public interface World {
*
* @param loc The location to spawn the creature
* @param type The creature to spawn
* @return Resulting Creature of this method, or null if it was unsuccessful
*/
- public Creature spawnCreature(Location loc, CreatureType type);
+ public LivingEntity spawnCreature(Location loc, CreatureType type);
/**
* Get a list of all entities in this World
@@ -303,9 +303,9 @@ public interface World {
* @param loc The location to spawn the creature
* @param type The creature to spawn
- * @return Resulting Creature of this method, or null if it was unsuccessful
+ * @return Resulting LivingEntity of this method, or null if it was unsuccessful
*/